==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningCategoryStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningCategoryStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningCategoryStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningCategoryStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.g(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningCategoryStyleEventArgsBaseDescriptionMetadata.b(a);
        a.t("AssigningCategoryStyleEventArgsBase", AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningCategoryStyleEventArgsBaseDescriptionMetadata, 'AssigningCategoryStyleEventArgsBaseDescriptionMetadata');
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningCategoryStyleEventArgsBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningCategoryStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningCategoryStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningCategoryStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningCategoryStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.j(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningCategoryStyleEventArgsBaseDescriptionMetadata.b(a);
        a.z("AssigningCategoryStyleEventArgsBase", AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningCategoryStyleEventArgsBaseDescriptionMetadata, 'AssigningCategoryStyleEventArgsBaseDescriptionMetadata');
    AssigningCategoryStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningCategoryStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningCategoryStyleEventArgsBaseDescriptionMetadata };
